@@ -9,8 +9,7 @@ options(contrasts=c('contr.treatment', 'contr.poly')) #ensure constrast type
 test2 <- data.frame(start=c(1, 2, 5, 2, 1, 7, 3, 4, 8, 8),
                     stop =c(2, 3, 6, 7, 8, 9, 9, 9,14,17),
                     event=c(1, 1, 1, 1, 1, 1, 1, 0, 0, 0),
-                    x    =c(1, 0, 0, 1, 0, 1, 1, 1, 0, 0) )
-fit0 <-coxph(Surv(start, stop, event) ~x, test2, iter=0, method='breslow')
+                    x    =c(1, 0, 0, 1, 0, 1, 1, 1, 0, 0))
 
 byhand <- function(beta, newx=0) {
     r <- exp(beta)
@@ -71,26 +70,28 @@ fit0 <-coxph(Surv(start, stop, event) ~x, test2, iter=0, method='breslow')
 truth0 <- byhand(0,0)
 aeq(truth0$loglik, fit0$loglik[1])
 aeq(1/truth0$imat, fit0$var)
-aeq(truth0$mart, fit0$resid)
+aeq(truth0$mart, fit0$residuals)
 aeq(truth0$scho, resid(fit0, 'schoen'))
 aeq(truth0$score, resid(fit0, 'score')) 
 sfit <- survfit(fit0, list(x=0), censor=FALSE)
 aeq(sfit$std.err^2, truth0$var)
 aeq(sfit$surv, truth0$surv)
+aeq(fit0$score, truth0$u^2/truth0$imat)
 
 beta1 <- truth0$u/truth0$imat
 fit1 <- coxph(Surv(start, stop, event) ~x, test2, iter=1, ties="breslow")
 aeq(beta1, coef(fit1))
 
 truth <- byhand(-0.084526081, 0)
-fit <- coxph(Surv(start, stop, event) ~x, test2, eps=1e-8, method='breslow')
+fit <- coxph(Surv(start, stop, event) ~x, test2, eps=1e-8, method='breslow',
+             nocenter= NULL)
 aeq(truth$loglik, fit$loglik[2])
 aeq(1/truth$imat, fit$var)
-aeq(truth$mart, fit$resid)
+aeq(truth$mart, fit$residuals)
 aeq(truth$scho, resid(fit, 'schoen'))
 aeq(truth$score, resid(fit, 'score'))
 expect <- predict(fit, type='expected', newdata=test2) #force recalc
-aeq(test2$event -fit$resid, expect) #tests the predict function
+aeq(test2$event -fit$residuals, expect) #tests the predict function
 
 sfit <- survfit(fit, list(x=0), censor=FALSE)
 aeq(sfit$std.err^2, truth$var) 
@@ -107,19 +108,19 @@ fit0 <- coxph(Surv(start, stop, event) ~ x + strata(group), test2b,
               iter=0, method="breslow")
 aeq(3*truth0$loglik, fit0$loglik[1])
 aeq(3*truth0$imat, 1/fit0$var)
-aeq(rep(truth0$mart,3), fit0$resid)
+aeq(rep(truth0$mart,3), fit0$residuals)
 aeq(rep(truth0$scho,3),  resid(fit0, 'schoen'))
 aeq(rep(truth0$score,3), resid(fit0, 'score')) 
 
 fit1 <- coxph(Surv(start, stop, event) ~ x + strata(group), test2b, 
               iter=1, method="breslow")
-aeq(fit1$coef, beta1)
+aeq(fit1$coefficients, beta1)
 
 fit3 <- coxph(Surv(start, stop, event) ~x + strata(group),
              test2b, eps=1e-8, method='breslow')
 aeq(3*truth$loglik, fit3$loglik[2])
 aeq(3*truth$imat, 1/fit3$var)
-aeq(rep(truth$mart,3), fit3$resid)
+aeq(rep(truth$mart,3), fit3$residuals)
 aeq(rep(truth$scho,3), resid(fit3, 'schoen'))
 aeq(rep(truth$score,3), resid(fit3, 'score'))
 
